@@ -1,4 +1,4 @@
-runmean <- function(x, y, fr = 1, tr = 0.2){
+runmean <- function(x, y, fr = 1, tr = 0.2, ...){
   #
   # running mean using interval method
   #
@@ -27,4 +27,4 @@ runmean <- function(x, y, fr = 1, tr = 0.2){
   rmd <- c(1:length(x))
   for(i in 1:length(x)) rmd[i] <- mean(y[near(x,x[i],fr)],tr)
   return(rmd)
-}
\ No newline at end of file
+}
